@@ -2,7 +2,8 @@
 
 """Assemble DOT source code and render it with Graphviz.
 
->>> dot = Digraph(comment='The Round Table')
+>>> import graphviz
+>>> dot = graphviz.Digraph(comment='The Round Table')
 
 >>> dot.node('A', 'King Arthur')
 >>> dot.node('B', 'Sir Bedevere the Wise')
@@ -24,12 +25,12 @@ digraph {
 }
 """
 
-from .dot import Graph, Digraph
-from .files import Source
-from .lang import escape, nohtml
 from .backend import (render, pipe, unflatten, version, view,
                       ENGINES, FORMATS, RENDERERS, FORMATTERS,
                       ExecutableNotFound, RequiredArgumentError)
+from .dot import Graph, Digraph
+from .files import Source
+from .lang import escape, nohtml
 
 __all__ = ['Graph', 'Digraph',
            'Source',
@@ -39,21 +40,21 @@ __all__ = ['Graph', 'Digraph',
            'ExecutableNotFound', 'RequiredArgumentError']
 
 __title__ = 'graphviz'
-__version__ = '0.16'
+__version__ = '0.17'
 __author__ = 'Sebastian Bank <sebastian.bank@uni-leipzig.de>'
 __license__ = 'MIT, see LICENSE.txt'
-__copyright__ = 'Copyright (c) 2013-2020 Sebastian Bank'
+__copyright__ = 'Copyright (c) 2013-2021 Sebastian Bank'
 
-#: Set of known layout commands used for rendering (``'dot'``, ``'neato'``, ...)
+#: :class:`set` of known layout commands used for rendering (``'dot'``, ``'neato'``, ...)
 ENGINES = ENGINES
 
-#: Set of known output formats for rendering (``'pdf'``, ``'png'``, ...)
+#: :class:`set` of known output formats for rendering (``'pdf'``, ``'png'``, ...)
 FORMATS = FORMATS
 
-#: Set of known output formatters for rendering (``'cairo'``, ``'gd'``, ...)
+#: :class:`set` of known output formatters for rendering (``'cairo'``, ``'gd'``, ...)
 FORMATTERS = FORMATTERS
 
-#: Set of known output renderers for rendering (``'cairo'``, ``'gd'``, ...)
+#: :class:`set` of known output renderers for rendering (``'cairo'``, ``'gd'``, ...)
 RENDERERS = RENDERERS
 
 ExecutableNotFound = ExecutableNotFound
