@@ -2,18 +2,19 @@
 
 r"""Assemble DOT source code objects.
 
->>> dot = Graph(comment=u'M\xf8nti Pyth\xf8n ik den H\xf8lie Grailen')
+>>> import graphviz
+>>> dot = graphviz.Graph(comment='M\xf8nti Pyth\xf8n ik den H\xf8lie Grailen')
 
->>> dot.node(u'M\xf8\xf8se')
->>> dot.node('trained_by', u'trained by')
->>> dot.node('tutte', u'TUTTE HERMSGERVORDENBROTBORDA')
+>>> dot.node('M\xf8\xf8se')
+>>> dot.node('trained_by', 'trained by')
+>>> dot.node('tutte', 'TUTTE HERMSGERVORDENBROTBORDA')
 
->>> dot.edge(u'M\xf8\xf8se', 'trained_by')
+>>> dot.edge('M\xf8\xf8se', 'trained_by')
 >>> dot.edge('trained_by', 'tutte')
 
 >>> dot.node_attr['shape'] = 'rectangle'
 
->>> print(dot.source.replace(u'\xf8', '0'))  #doctest: +NORMALIZE_WHITESPACE
+>>> print(dot.source.replace('\xf8', '0'))  #doctest: +NORMALIZE_WHITESPACE
 // M0nti Pyth0n ik den H0lie Grailen
 graph {
     node [shape=rectangle]
@@ -59,7 +60,7 @@ class Dot(files.File):
         self.name = name
         self.comment = comment
 
-        super(Dot, self).__init__(filename, directory, format, engine, encoding)
+        super().__init__(filename, directory, format, engine, encoding)
 
         self.graph_attr = dict(graph_attr) if graph_attr is not None else {}
         self.node_attr = dict(node_attr) if node_attr is not None else {}
@@ -70,7 +71,7 @@ class Dot(files.File):
         self.strict = strict
 
     def _kwargs(self):
-        result = super(Dot, self)._kwargs()
+        result = super()._kwargs()
         result.update(name=self.name,
                       comment=self.comment,
                       graph_attr=dict(self.graph_attr),
@@ -105,7 +106,7 @@ class Dot(files.File):
         yield head % (self._quote(self.name) + ' ' if self.name else '')
 
         for kw in ('graph', 'node', 'edge'):
-            attrs = getattr(self, '%s_attr' % kw)
+            attrs = getattr(self, f'{kw}_attr')
             if attrs:
                 yield self._attr % (kw, self._attr_list(None, attrs))
 
@@ -182,8 +183,8 @@ class Dot(files.File):
         See the :ref:`usage examples in the User Guide <attributes>`.
         """
         if kw is not None and kw.lower() not in ('graph', 'node', 'edge'):
-            raise ValueError('attr statement must target graph, node, or edge: '
-                '%r' % kw)
+            raise ValueError('attr statement must target graph, node, or edge:'
+                             f' {kw!r}')
         if attrs or _attributes:
             if kw is None:
                 a_list = self._a_list(None, attrs, _attributes)
@@ -238,8 +239,8 @@ class Dot(files.File):
             raise ValueError('graph must be sole argument of subgraph()')
 
         if graph.directed != self.directed:
-            raise ValueError('%r cannot add subgraph of different kind:'
-                             ' %r' % (self, graph))
+            raise ValueError(f'{self!r} cannot add subgraph of different kind:'
+                             f' {graph!r}')
 
         lines = ['\t' + line for line in graph.__iter__(subgraph=True)]
         self.body.extend(lines)
